@@ -295,6 +295,7 @@ static int ltspfs_getattr(const char *path, struct stat *stbuf)
     char inbuf[LTSP_MAXBUF];
     char *ptr = (char *) path;
     int opcode = LTSPFS_GETATTR;
+    unsigned int nlink = (unsigned int) stbuf->st_nlink;
     int res;
     uid_t uid;
     gid_t gid;
@@ -324,7 +325,7 @@ static int ltspfs_getattr(const char *path, struct stat *stbuf)
         return -EACCES;
     if (!xdr_u_int(&in, &stbuf->st_mode))
         return -EACCES;
-    if (!xdr_u_int(&in, &stbuf->st_nlink))
+    if (!xdr_u_int(&in, &nlink))
         return -EACCES;
     if (!xdr_u_int(&in, &uid))
         return -EACCES;
@@ -780,12 +781,13 @@ ltspfs_read(const char *path, char *buf, size_t size, off_t offset,
     int opcode = LTSPFS_READ;
     char *ptr = (char *) path;
     int res, returned;
+    unsigned int usize = (unsigned int) size;
     (void) fi;
 
     init_pkt(&in, &out, inbuf, outbuf);          /* Initialize packets */
 
     xdr_int(&out, &opcode);                      /* build opcode */
-    xdr_u_int(&out, &size);                      /* build packet size */
+    xdr_u_int(&out, &usize);                     /* build packet size */
     xdr_longlong_t(&out, &offset);               /* build file offset size */
     xdr_string(&out, &ptr, PATH_MAX);            /* build path */
 
@@ -836,13 +838,14 @@ ltspfs_write(const char *path, const char *buf, size_t size,
     int opcode = LTSPFS_WRITE;
     char *ptr = (char *) path;
     int res, returned;
+    unsigned int usize = (unsigned int) size;
 
     (void) fi;
 
     init_pkt(&in, &out, inbuf, outbuf);          /* Initialize packets */
 
     xdr_int(&out, &opcode);                      /* build opcode */
-    xdr_u_int(&out, &size);                      /* build packet size */
+    xdr_u_int(&out, &usize);                     /* build packet size */
     xdr_longlong_t(&out, &offset);               /* build file offset */
     xdr_string(&out, &ptr, PATH_MAX);            /* build path */
 
@@ -883,6 +886,9 @@ static int ltspfs_statfs(const char *path, struct statfs *stbuf)
     int opcode = LTSPFS_STATFS;
     char *ptr = (char *) path;
     int ret;
+    int f_type = (int)stbuf->f_type;
+    int f_bsize = (int)stbuf->f_bsize;
+    int f_namelen = (int)stbuf->f_namelen;
 
     init_pkt(&in, &out, inbuf, outbuf);          /* Initialize packets */
 
@@ -901,14 +907,14 @@ static int ltspfs_statfs(const char *path, struct statfs *stbuf)
     if (ret)
         return parse_return(&in);
 
-    xdr_int(&in, &stbuf->f_type);                /* type of fs */
-    xdr_int(&in, &stbuf->f_bsize);               /* optimal transfer block sz */
+    xdr_int(&in, &f_type);                       /* type of fs */
+    xdr_int(&in, &f_bsize);                      /* optimal transfer block sz */
     xdr_u_longlong_t(&in, &stbuf->f_blocks);     /* total data blocks in fs */
     xdr_u_longlong_t(&in, &stbuf->f_bfree);      /* free blks in fs */
     xdr_u_longlong_t(&in, &stbuf->f_bavail);     /* free blks avail to non-su */
     xdr_u_longlong_t(&in, &stbuf->f_files);      /* total file nodes in fs */
     xdr_u_longlong_t(&in, &stbuf->f_ffree);      /* free file nodes in fs */
-    xdr_int(&in, &stbuf->f_namelen);
+    xdr_int(&in, &f_namelen);
 
     return OK;
 }
