@@ -240,6 +240,7 @@ void ltspfs_getattr(int sockfd, XDR * in)
     char output[LTSP_MAXBUF];
     int i;
     struct stat stbuf;
+    unsigned int nlink;
 
     if (get_fn(sockfd, in, path)) {
         if (debug)
@@ -260,7 +261,8 @@ void ltspfs_getattr(int sockfd, XDR * in)
     xdr_u_longlong_t(&out, &(stbuf.st_dev));     /* device */
     xdr_u_longlong_t(&out, &(stbuf.st_ino));     /* inode */
     xdr_u_int(&out, &(stbuf.st_mode));           /* protection */
-    xdr_u_int(&out, &(stbuf.st_nlink));          /* number of hard links */
+    xdr_u_int(&out, &nlink);
+    stbuf.st_nlink = (nlink_t) nlink;
     xdr_u_int(&out, &(stbuf.st_uid));            /* user ID of owner */
     xdr_u_int(&out, &(stbuf.st_gid));            /* group ID of owner */
     xdr_u_longlong_t(&out, &(stbuf.st_rdev));    /* device type */
@@ -718,15 +720,18 @@ void ltspfs_read(int sockfd, XDR * in)
     int i;
     int fd;
     int result;
+    unsigned int usize;
     size_t size;
     off_t offset;
     char *buf;
 
-    if (!xdr_u_int(in, &size)) {                 /* Get the size */
+    if (!xdr_u_int(in, &usize)) {                 /* Get the size */
         eacces(sockfd);
         return;
     }
 
+    size = (size_t) usize;
+
     if (!xdr_longlong_t(in, &offset)) {          /* Get the offset */
         eacces(sockfd);
         return;
@@ -795,14 +800,17 @@ void ltspfs_write(int sockfd, XDR * in)
     int fd;
     int result;
     size_t size;
+    unsigned int usize;
     off_t offset;
     char *buf;
 
-    if (!xdr_u_int(in, &size)) {                 /* Get the size */
+    if (!xdr_u_int(in, &usize)) {                /* Get the size */
         eacces(sockfd);
         return;
     }
 
+    size = (size_t) usize;
+
     if (!xdr_longlong_t(in, &offset)) {          /* Get the offset */
         eacces(sockfd);
         return;
@@ -869,6 +877,7 @@ void ltspfs_statfs(int sockfd, XDR * in)
     char output[LTSP_MAXBUF];
     struct statfs stbuf;
     int i;
+    int f_type, f_bsize, f_namelen;
 
     if (get_fn(sockfd, in, path)) {              /* Get the path */
         eacces(sockfd);
@@ -886,14 +895,17 @@ void ltspfs_statfs(int sockfd, XDR * in)
     xdr_int(&out, &i);                           /* dummy length */
     i = LTSP_STATUS_OK;                          /* OK status */
     xdr_int(&out, &i);
-    xdr_int(&out, &stbuf.f_type);                /* type of fs */
-    xdr_int(&out, &stbuf.f_bsize);               /* optimal transfer block sz */
+    xdr_int(&out, &f_type);                      /* type of fs */
+    xdr_int(&out, &f_bsize);                     /* optimal transfer block sz */
     xdr_u_longlong_t(&out, &stbuf.f_blocks);     /* total data blocks in fs */
     xdr_u_longlong_t(&out, &stbuf.f_bfree);      /* free blks in fs */
     xdr_u_longlong_t(&out, &stbuf.f_bavail);     /* free blks avail to non-su */
     xdr_u_longlong_t(&out, &stbuf.f_files);      /* total file nodes in fs */
     xdr_u_longlong_t(&out, &stbuf.f_ffree);      /* free file nodes in fs */
-    xdr_int(&out, &stbuf.f_namelen);             /* max length of filenames */
+    xdr_int(&out, &f_namelen);                   /* max length of filenames */
+    stbuf.f_type = (__SWORD_TYPE) f_type;
+    stbuf.f_bsize = (__SWORD_TYPE) f_bsize;
+    stbuf.f_namelen = (__SWORD_TYPE) f_namelen;
     i = xdr_getpos(&out);                        /* Get current position */
     xdr_setpos(&out, 0);                         /* rewind to the beginning */
     xdr_int(&out, &i);                           /* re-write proper length */
@@ -966,21 +978,21 @@ void handle_mount(int sockfd, XDR * in)
 void handle_auth(int sockfd, XDR * in)
 {
     char recdtoken[64];
-    size_t auth_size;
+    int auth_size;
     char authtoken[64];
-    ssize_t authtokensize;
+    int authtokensize;
     int authfile, i;
 
     /*
      * Get our auth size.
      */
 
-    if (!xdr_u_int(in, &auth_size)) {            /* Get the size */
+    if (!xdr_int(in, &auth_size)) {            /* Get the size */
         eacces(sockfd);
         return;
     }
 
-    if (auth_size >= sizeof recdtoken) {
+    if (auth_size >= (int) sizeof recdtoken) {
         eacces(sockfd);
         return;
     }
